Generate vi compatible tags for multiple languages.
Uses the tags queries defined in the various official language parsers to detect tags.
Usage
ⓘ
use treetags::Parser;
let file_path_relative_to_tag_file = "path/to/source_file.rs"; // file path relative to tag file
let extension = "rs";
let file_path_str = "source.file"; // file path relative to current directory
let mut parser = Parser::new();
let tags = parser.parse_file(&file_path_relative_to_tag_file, &file_path, extension);Re-exports
pub use config::Config;pub use parser::Parser;pub use tag::parse_tag_file;pub use tag::Tag;
Modules
- built_
in_ grammars - config
- Configuration handling for the tag generator application.
- file_
finder - Module for finding files and tag files in the filesystem.
- parser
- Parser Module
- queries
- shell_
to_ regex - split_
by_ newlines - tag
- Tag Module
- tag_
processor - Module for processing source files and generating tags.
- tag_
writer - Module for writing tag data to files.
- tags_
config - user_
grammars